@@ -31,6 +31,12 @@
 #define RUBY_SYMBOL_EXPORT_BEGIN _Pragma("GCC visibility push(default)")
 #define RUBY_SYMBOL_EXPORT_END _Pragma("GCC visibility pop")
 #define HAVE_STMT_AND_DECL_IN_EXPR 1
+#define HAVE_PTHREAD_H 1
+#define _REENTRANT 1
+#define _THREAD_SAFE 1
+#define HAVE_LIBPTHREAD 1
+#define THREAD_IMPL_H "thread_pthread.h"
+#define THREAD_IMPL_SRC "thread_pthread.c"
 #define BROKEN_CRYPT 1
 #define HAVE_CRT_EXTERNS_H 1
 #define HAVE_LIBDL 1
@@ -47,7 +53,10 @@
 #define HAVE_LOCALE_H 1
 #define HAVE_MALLOC_MALLOC_H 1
 #define HAVE_PWD_H 1
+#define HAVE_SANITIZER_ASAN_INTERFACE_H 1
+#define HAVE_SANITIZER_MSAN_INTERFACE_H 1
 #define HAVE_STDALIGN_H 1
+#define HAVE_STDIO_H 1
 #define HAVE_SYS_ATTR_H 1
 #define HAVE_SYS_FCNTL_H 1
 #define HAVE_SYS_FILE_H 1
@@ -64,6 +73,7 @@
 #define HAVE_TIME_H 1
 #define HAVE_UCONTEXT_H 1
 #define HAVE_UTIME_H 1
+#define HAVE_STDATOMIC_H 1
 #define HAVE_X86INTRIN_H 1
 #if defined(__x86_64__)
 #define HAVE_X86INTRIN_H 1
@@ -85,7 +95,6 @@
 #define SIZEOF_TIME_T 8
 #define SIZEOF_CLOCK_T 8
 #define PACKED_STRUCT(x) x __attribute__((packed))
-#define USE_UNALIGNED_MEMBER_ACCESS 1
 #define PRI_LL_PREFIX "ll"
 #define HAVE_PID_T 1
 #define rb_pid_t pid_t
@@ -150,13 +159,10 @@
 #define DEPRECATED_BY(n,x) __attribute__ ((__deprecated__("by "#n))) x
 #define NOINLINE(x) __attribute__ ((__noinline__)) x
 #define ALWAYS_INLINE(x) __attribute__ ((__always_inline__)) x
-#define NO_SANITIZE(san, x) __attribute__ ((__no_sanitize__(san))) x
 #define NO_SANITIZE_ADDRESS(x) __attribute__ ((__no_sanitize_address__)) x
 #define NO_ADDRESS_SAFETY_ANALYSIS(x) __attribute__ ((__no_address_safety_analysis__)) x
 #define WARN_UNUSED_RESULT(x) __attribute__ ((__warn_unused_result__)) x
 #define MAYBE_UNUSED(x) __attribute__ ((__unused__)) x
-#define ERRORFUNC(mesg,x) __attribute__ ((__error__ mesg)) x
-#define WARNINGFUNC(mesg,x) __attribute__ ((__warning__ mesg)) x
 #define WEAK(x) __attribute__ ((__weak__)) x
 #define HAVE_FUNC_WEAK 1
 #define RUBY_CXX_DEPRECATED(msg) __attribute__((__deprecated__(msg)))
@@ -164,7 +170,7 @@
 #define FUNC_CDECL(x) __attribute__ ((__cdecl__)) x
 #define HAVE_GCC_ATOMIC_BUILTINS 1
 #define HAVE_GCC_SYNC_BUILTINS 1
-#define UNREACHABLE __builtin_unreachable()
+#define HAVE___BUILTIN_UNREACHABLE 1
 #define RUBY_FUNC_EXPORTED __attribute__ ((__visibility__("default"))) extern
 #define RUBY_FUNC_NONNULL(n,x) __attribute__ ((__nonnull__(n))) x
 #define RUBY_FUNCTION_NAME_STRING __func__
@@ -254,6 +260,9 @@
 #define HAVE_ARC4RANDOM_BUF 1
 #define HAVE_ATAN2L 1
 #define HAVE_ATAN2F 1
+#define HAVE_DECL_ATOMIC_SIGNAL_FENCE 1
+#define HAVE_CHMOD 1
+#define HAVE_CHOWN 1
 #define HAVE_CHROOT 1
 #define HAVE_CLOCK_GETTIME 1
 #define HAVE_COSH 1
@@ -261,6 +270,10 @@
 #define HAVE_DLOPEN 1
 #define HAVE_DLADDR 1
 #define HAVE_ENDGRENT 1
+#define HAVE_EXECL 1
+#define HAVE_EXECLE 1
+#define HAVE_EXECV 1
+#define HAVE_EXECVE 1
 #define HAVE_FCOPYFILE 1
 #define HAVE_FCHMOD 1
 #define HAVE_FCHOWN 1
@@ -273,7 +286,10 @@
 #define HAVE_FTRUNCATE 1
 #define HAVE_GETATTRLIST 1
 #define HAVE_GETCWD 1
+#define HAVE_GETEGID 1
 #define HAVE_GETENTROPY 1
+#define HAVE_GETEUID 1
+#define HAVE_GETGID 1
 #define HAVE_GETGRNAM 1
 #define HAVE_GETGRNAM_R 1
 #define HAVE_GETGROUPS 1
@@ -281,6 +297,7 @@
 #define HAVE_GETLOGIN_R 1
 #define HAVE_GETPGID 1
 #define HAVE_GETPGRP 1
+#define HAVE_GETPPID 1
 #define HAVE_GETPRIORITY 1
 #define HAVE_GETPWNAM 1
 #define HAVE_GETPWNAM_R 1
@@ -289,11 +306,13 @@
 #define HAVE_GETRLIMIT 1
 #define HAVE_GETSID 1
 #define HAVE_GETTIMEOFDAY 1
+#define HAVE_GETUID 1
 #define HAVE_GMTIME_R 1
 #define HAVE_GRANTPT 1
 #define HAVE_INITGROUPS 1
 #define HAVE_IOCTL 1
 #define HAVE_ISSETUGID 1
+#define HAVE_KILL 1
 #define HAVE_KILLPG 1
 #define HAVE_LCHMOD 1
 #define HAVE_LCHOWN 1
@@ -313,7 +332,11 @@
 #define HAVE_MKTIME 1
 #define HAVE_MMAP 1
 #define HAVE_OPENAT 1
+#define HAVE_PCLOSE 1
+#define HAVE_PIPE 1
 #define HAVE_POLL 1
+#define HAVE_POPEN 1
+#define HAVE_POSIX_MADVISE 1
 #define HAVE_POSIX_MEMALIGN 1
 #define HAVE_PREAD 1
 #define HAVE_PWRITE 1
@@ -345,11 +368,14 @@
 #define HAVE_SYMLINK 1
 #define HAVE_SYSCALL 1
 #define HAVE_SYSCONF 1
+#define HAVE_SYSTEM 1
 #define HAVE_TANH 1
 #define HAVE_TELLDIR 1
 #define HAVE_TIMEGM 1
 #define HAVE_TIMES 1
 #define HAVE_TRUNCATE 1
+#define HAVE_TZSET 1
+#define HAVE_UMASK 1
 #define HAVE_UNSETENV 1
 #define HAVE_UTIMENSAT 1
 #define HAVE_UTIMES 1
@@ -360,7 +386,6 @@
 #if !defined __STDC_WANT_LIB_EXT1__
 #define __STDC_WANT_LIB_EXT1__ 1
 #endif /* !defined __STDC_WANT_LIB_EXT1__ */
-#define HAVE_BUILTIN___BUILTIN_ALLOCA_WITH_ALIGN 1
 #define HAVE_BUILTIN___BUILTIN_ASSUME_ALIGNED 1
 #define HAVE_BUILTIN___BUILTIN_BSWAP16 1
 #define HAVE_BUILTIN___BUILTIN_BSWAP32 1
@@ -372,9 +397,6 @@
 #define HAVE_BUILTIN___BUILTIN_CLZLL 1
 #define HAVE_BUILTIN___BUILTIN_CTZ 1
 #define HAVE_BUILTIN___BUILTIN_CTZLL 1
-#define HAVE_BUILTIN___BUILTIN_ADD_OVERFLOW 1
-#define HAVE_BUILTIN___BUILTIN_SUB_OVERFLOW 1
-#define HAVE_BUILTIN___BUILTIN_MUL_OVERFLOW 1
 #define HAVE_BUILTIN___BUILTIN_CONSTANT_P 1
 #define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR 1
 #define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR_CONSTANT_P 1
@@ -395,9 +417,6 @@
 #define HAVE__SC_CLK_TCK 1
 #define STACK_GROW_DIRECTION -1
 #define COROUTINE_H "coroutine/amd64/Context.h"
-#define _REENTRANT 1
-#define _THREAD_SAFE 1
-#define HAVE_LIBPTHREAD 1
 #define HAVE_SCHED_YIELD 1
 #define HAVE_PTHREAD_ATTR_SETINHERITSCHED 1
 #define HAVE_PTHREAD_ATTR_GETSTACK 1
@@ -416,6 +435,10 @@
 #define HAVE_LIBPROC_H 1
 #define HAVE_EXECINFO_H 1
 #define HAVE_LIBUNWIND_H 1
+#define HAVE_MACH_TASK_H 1
+#define HAVE_MACH_MACH_INIT_H 1
+#define HAVE_MACH_MACH_PORT_H 1
+#define HAVE_MACH_TASK_EXCEPTION_PORTS 1
 #define HAVE_BACKTRACE 1
 #define BROKEN_BACKTRACE 1
 #define DLEXT_MAXLEN 7
@@ -427,8 +450,6 @@
 #define RUBY_LONGJMP(env,val) siglongjmp((env),val)
 #define RUBY_JMP_BUF sigjmp_buf
 #define USE_MJIT 1
-#define HAVE_PTHREAD_H 1
-#define THREAD_IMPL_H "thread_pthread.h"
-#define THREAD_IMPL_SRC "thread_pthread.c"
+#define USE_YJIT 0
 #define RUBY_PLATFORM "x86_64-darwin14"
 #endif /* INCLUDE_RUBY_CONFIG_H */
